"use strict";
// *****************************************************************************
// Copyright (C) 2023 EclipseSource and others.
//
// This program and the accompanying materials are made available under the
// terms of the Eclipse Public License v. 2.0 which is available at
// http://www.eclipse.org/legal/epl-2.0.
//
// This Source Code may also be made available under the following Secondary
// Licenses when the conditions for such availability set forth in the Eclipse
// Public License v. 2.0 are satisfied: GNU General Public License, version 2
// with the GNU Classpath Exception which is available at
// https://www.gnu.org/software/classpath/license.html.
//
// SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0
// *****************************************************************************
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LanguageIconLabelProvider = void 0;
const inversify_1 = require("inversify");
const common_1 = require("../common");
const icon_theme_service_1 = require("./icon-theme-service");
const language_service_1 = require("./language-service");
let LanguageIconLabelProvider = class LanguageIconLabelProvider {
    constructor() {
        this.onDidChangeEmitter = new common_1.Emitter();
    }
    init() {
        this.languageService.onDidChangeIcon(() => this.fireDidChange());
    }
    canHandle(element) {
        const current = this.iconThemeService.getDefinition(this.iconThemeService.current);
        return (current === null || current === void 0 ? void 0 : current.showLanguageModeIcons) === true && this.languageService.getIcon(element) ? Number.MAX_SAFE_INTEGER : 0;
    }
    getIcon(element) {
        const language = this.languageService.detectLanguage(element);
        return this.languageService.getIcon(language.id);
    }
    get onDidChange() {
        return this.onDidChangeEmitter.event;
    }
    fireDidChange() {
        this.onDidChangeEmitter.fire({
            affects: element => this.canHandle(element) > 0
        });
    }
};
__decorate([
    (0, inversify_1.inject)(icon_theme_service_1.IconThemeService),
    __metadata("design:type", icon_theme_service_1.IconThemeService)
], LanguageIconLabelProvider.prototype, "iconThemeService", void 0);
__decorate([
    (0, inversify_1.inject)(language_service_1.LanguageService),
    __metadata("design:type", language_service_1.LanguageService)
], LanguageIconLabelProvider.prototype, "languageService", void 0);
__decorate([
    (0, inversify_1.postConstruct)(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], LanguageIconLabelProvider.prototype, "init", null);
LanguageIconLabelProvider = __decorate([
    (0, inversify_1.injectable)()
], LanguageIconLabelProvider);
exports.LanguageIconLabelProvider = LanguageIconLabelProvider;
//# sourceMappingURL=language-icon-provider.js.map